/****************************************************************************
 *
 * @author Dilshod Mukhtarov <dilshodm(at)gmail.com>
 * May 2019
 *
 ****************************************************************************/

/*
 * This firmware is capturing A0 to A7 analog ports and sends to host on request
 * 
 * From host you send query "q\n"
 * and arduino replies:
 * "r 400 300 110 330 200 600 1000\n"
 * 
 * where 'r' - is reply signature
 * and then up to 8 values of adc reads (10 bit: 0-1023)
 */


// ATTENTION!
// Set this number to 8 for Arduino Leonardo and to 6 for Arduino UNO
// Pay attention, there is no '=' sign here!

#define NUMBER_OF_PINS 6



// ==========================================================================

#if NUMBER_OF_PINS == 8
int inputPins[NUMBER_OF_PINS] = { A0, A1, A2, A3, A4, A5, A6, A7 };
#else 
int inputPins[NUMBER_OF_PINS] = { A0, A1, A2, A3, A4, A5 };
#endif
const String NUMBER_OF_PINS_STRING = String(NUMBER_OF_PINS)
;

const int SERIAL_TIMETOUT_MS = 5; // Serial port timeout in milliseconds

void setup() {
    // put your setup code here, to run once:
    Serial.begin(115200, SERIAL_8N1);
    Serial.setTimeout(SERIAL_TIMETOUT_MS);
    while (!Serial) {
        ; // wait for serial port to connect. Needed for native USB port only
    }
    
}

void loop() {
    String reply("r");
    
    // Read ADC values
    for (int i = 0; i < NUMBER_OF_PINS; ++i) {
        int adcValue = analogRead(inputPins[i]);
        reply += ' ' + String(adcValue);
    }
    
    Serial.println(reply);

    Serial.flush();
    delay(5);
}
